function [res_struct] = ConfigPerturbedPendulumModel()
% The nominal pendulum model, which represents a perturbed version of the
% true pendulum model in ConfigPendulumModel.m.
%
% --
% Self-tuning LQR, Trimpe et al. IFAC World Congress 2014 paper
%
% Copyright:
% Sebastian Trimpe
% Max-Planck-Institute for Intelligent Systems
% Autonomous Motion Department
% strimpe(at)tuebingen.mpg.de
%
% Revision history
% [13.11.13]   first version to be published


%% Configuration
% Set parameters.

% Model parameters
param_m = 0.8*5.3;  % pendulum mass, []=kg, PERTURBED
param_l = 0.8*0.65; % pendulum length, []=m, PERTURBED
param_g = 9.81; % gravity constant, []=m/s^2

Ts = 1/100;     % sampling time


%% Linear pendulum model
% Continuous time model (see paper).
A = [0 1; param_g/param_l 0];
B = [0; 1/(param_m*param_l^2)];
sysc = ss(A,B,eye(2),0);

% Discretize at a sampling rate of 1/100s.
sysd = c2d(sysc,Ts);


%% Relevant results
res_struct.sysd = sysd;     % Discrete-time state space model